<?php

/**
 * @file
 * Contains \Drupal\video_embed_ted\Plugin\video_embed_field\Provider\Ted.
 */

namespace Drupal\video_embed_ted\Plugin\video_embed_field\Provider;

use Drupal\video_embed_field\ProviderPluginBase;
use Guzzle\Http\Client;
use Drupal\Component\Utility\SafeMarkup;

/**
 * @VideoEmbedProvider(
 *   id = "ted",
 *   title = @Translation("Ted")
 * )
 */
class Ted extends ProviderPluginBase {

  /**
   * {@inheritdoc}
   */
  public function renderEmbedCode($width, $height, $autoplay) {
    return [
      '#type' => 'html_tag',
      '#tag' => 'iframe',
      '#attributes' => [
        'width' => $width,
        'height' => $height,
        'frameborder' => '0',
        'scrolling' => 'no',
        'webkitAllowFullScreen' => 'webkitAllowFullScreen',
        'mozallowfullscreen' => 'mozallowfullscreen',
        'allowfullscreen' => 'allowfullscreen',
        'src' => sprintf('https://embed-ssl.ted.com/talks/%s.html', $this->getVideoId(), $autoplay),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getRemoteThumbnailUrl() {
    $image_url = $this->ted_get_thumbnail_url($this->getVideoId());
    if ($image_url) {
      return $image_url;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public static function getIdFromInput($input) {
    
    $matches = array();
    preg_match('#/talks/([A-Za-z0-9_-]+)(\.html)?#', $input, $matches);
    if ($matches && !empty($matches[1])) {
      // Security check, this is the only place where we use user input.
      return SafeMarkup::checkPlain($matches[1]);
    }
    // Otherwise return FALSE.
    return FALSE;
  }
  
  /**
   * 
   * @param type $id
   * @return boolean|array
   */
  public static function ted_get_thumbnail_url($id) {
//    die('aaa');
    $matches = array();
    $url = 'https://embed-ssl.ted.com/talks/' . $id . '.html';
    $client = \Drupal::httpClient();
    $response = $client->get($url);
    $response_body = $response->getBody();
    if (!empty($response_body)) {
      // Get image from <div class='Embeddable__landing__poster' role='button' style='background-image:url(GET_VALUE)
      preg_match("/Embeddable__landing__poster.*image:url\((.*)\)/", $response_body, $matches); 
    }
    else {
      return FALSE;
    }
    if (!empty($matches[1])) {
      return $matches[1];
    }
    else {
      return FALSE;
    }
  }

}
